@@ -2,11 +2,10 @@ from .command import *
 from .group import *
 from .engine import *
 from .injected_command import *
-from .passcommand import *
+from .injectcommand import *
 from .parse import *
-from .decorator import *
 from .exceptions import *
 
-__all__ = ["Engine", "group", "passcommand"]
+__all__ = ["Engine", "group", "injectcommand", "Parser"]
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
