@@ -1,4 +1,4 @@
-from .protocols import DecoratorCommand
+from .protocols import Command
 
 __all__ = ["Group", "group"]
 
@@ -10,15 +10,15 @@ class Group:
 
 
 def group(name: str):
-    def decorator(cmd: DecoratorCommand):
-        if not cmd.last_engine.groups.get(name):
+    def decorator(cmd: Command):
+        if not cmd.__last_engine__.groups.get(name):
             group = Group(name=name)
-            cmd.last_engine.groups[name] = group
-            cmd = cmd.last_engine.__commands__[cmd.name]
+            cmd.__last_engine__.groups[name] = group
+            cmd = cmd.__last_engine__.__commands__[cmd.name]
             if not cmd.groups.get(name):
                 cmd.groups[name] = group
         else:
-            group = cmd.last_engine.groups[name]
+            group = cmd.__last_engine__.groups[name]
         group.commands.append(cmd)
         return cmd
 
